@@ -1,4 +1,4 @@
-__version__ = "1.1.3"
+__version__ = "1.1.8"
 
 import kappadata.caching
 import kappadata.common
@@ -10,8 +10,6 @@ import kappadata.transforms.norm
 import kappadata.wrappers
 import kappadata.wrappers.dataset_wrappers
 import kappadata.wrappers.sample_wrappers
-# batch_samplers
-from .batch_samplers.infinite_batch_sampler import InfiniteBatchSampler
 # caching
 from .caching.shared_dict_dataset import SharedDictDataset
 # collators
@@ -36,6 +34,11 @@ from .datasets.kd_subset import KDSubset
 from .datasets.kd_wrapper import KDWrapper
 # factory
 from .factory import object_to_transform
+# samplers
+from .samplers.interleaved_sampler import InterleavedSampler, InterleavedSamplerConfig
+# samplers.batch_samplers
+from .samplers.batch_samplers import InfiniteBatchSampler
+from .samplers.batch_samplers import InterleavedBatchSampler
 # transforms base
 from .transforms.base import KDComposeTransform
 from .transforms.base import KDIdentityTransform
@@ -73,6 +76,7 @@ from .utils.transform_utils import (
     get_norm_transform,
     get_x_transform,
 )
+from .utils.color_histogram import color_histogram
 # wrappers.dataset_wrappers
 from .wrappers.dataset_wrappers.class_filter_wrapper import ClassFilterWrapper
 from .wrappers.dataset_wrappers.classwise_subset_wrapper import ClasswiseSubsetWrapper
