@@ -1,7 +1,7 @@
 from kappadata.common.transforms.byol_transforms import BYOLTransform0, BYOLTransform1
-from kappadata.wrappers.sample_wrappers.multi_view_wrapper import MultiViewWrapper
+from kappadata.wrappers.sample_wrappers.kd_multi_view_wrapper import KDMultiViewWrapper
 
 
-class BYOLMultiViewWrapper(MultiViewWrapper):
+class BYOLMultiViewWrapper(KDMultiViewWrapper):
     def __init__(self, dataset):
         super().__init__(dataset=dataset, configs=[BYOLTransform0(), BYOLTransform1()])
